@@ -1,19 +1,32 @@
 mod modules;
 
 use std::path::PathBuf;
-
 use structopt::StructOpt;
 
-use modules::{bak::bak, gr::gr};
+use modules::{bak::bak, debak::debak, gr::gr};
 
 #[derive(StructOpt)]
-#[structopt(name = "tinytools")]
+#[structopt(
+    name = "tinytools",
+    global_settings(&[structopt::clap::AppSettings::ColoredHelp])
+)]
 enum TT {
     #[structopt(name = "bak")]
     /// Append a tilde (~) to the names of given files/directories.
     Bak {
         #[structopt(
-            help = "The file(s)/director(y/ies) to append tilde.",
+            help = "The file(s)/director(y/ies) to be renamed.",
+            parse(from_os_str)
+        )]
+        sources: Vec<PathBuf>,
+        #[structopt(long = "--quiet", short = "-q", help = "Be quiet.")]
+        quiet: bool,
+    },
+    #[structopt(name = "debak")]
+    /// Pop a tilde (~) from the names of given files/directories
+    Debak {
+        #[structopt(
+            help = "The file(s)/director(y/ies) to be renamed.",
             parse(from_os_str)
         )]
         sources: Vec<PathBuf>,
@@ -30,6 +43,9 @@ fn main() -> Result<(), String> {
         TT::Bak { mut sources, quiet } => {
             bak(&mut sources, quiet)?;
         }
+        TT::Debak { mut sources, quiet } => {
+            debak(&mut sources, quiet)?;
+        }
         TT::Gr {} => {
             gr()?;
         }
